/*
    Copyright (C) 2007  Miklos Szeredi <miklos@szeredi.hu>

    This program can be distributed under the terms of the GNU GPL.
*/

#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include <sys/mount.h>

#ifndef MNT_LAZY
#define MNT_LAZY 2
#endif

static void usage(const char *progname)
{
	fprintf(stderr, 
		"usage: %s [-flhV] mountpoint\n"
		"  -h               help\n"
		"  -V               version\n"
		"  -l               lazy\n"
		"  -f               force\n"
		, progname);
}

int main(int argc, char *argv[])
{
	char *target;
	int flags = 0;
	int res;

        while (1) {
		int c = getopt(argc, argv, "flVh");
		if (c == -1)
			break;

		switch (c) {
		case 'f':
			flags |= MNT_FORCE;
			break;

                case 'l':
			flags |= MNT_LAZY;
			break;

		case 'V':
			fprintf(stderr, "version: %s\n", VERSION);
			exit(0);

		case 'h':
		case '?':
			usage(argv[0]);
			exit(1);
		}
	}

	if (optind < argc)
		target = argv[optind++];
	else {
		usage(argv[0]);
		exit(1);
	}

	res = umount2(target, flags);
	if (res == -1) {
		perror(target);
		exit(1);
	}
	return 0;
}
